complete -c cog -n "__fish_use_subcommand" -s v -l verbose -d 'The level of verbosity: -v for ERROR, -vv for WARNING, -vvv for INFO'
complete -c cog -n "__fish_use_subcommand" -s q -l quiet -d 'Silence all output, no matter the value of verbosity'
complete -c cog -n "__fish_use_subcommand" -s h -l help -d 'Print help'
complete -c cog -n "__fish_use_subcommand" -s V -l version -d 'Print version'
complete -c cog -n "__fish_use_subcommand" -f -a "check" -d 'Verify all commit messages against the conventional commit specification'
complete -c cog -n "__fish_use_subcommand" -f -a "commit" -d 'Create a new conventional commit'
complete -c cog -n "__fish_use_subcommand" -f -a "edit" -d 'Interactively rename invalid commit messages'
complete -c cog -n "__fish_use_subcommand" -f -a "log" -d 'Like git log but for conventional commits'
complete -c cog -n "__fish_use_subcommand" -f -a "verify" -d 'Verify a single commit message'
complete -c cog -n "__fish_use_subcommand" -f -a "changelog" -d 'Display a changelog for the given commit oid range'
complete -c cog -n "__fish_use_subcommand" -f -a "get-version" -d 'Get current version'
complete -c cog -n "__fish_use_subcommand" -f -a "bump" -d 'Commit changelog from latest tag to HEAD and create new tag'
complete -c cog -n "__fish_use_subcommand" -f -a "init" -d 'Install cog config files'
complete -c cog -n "__fish_use_subcommand" -f -a "install-hook" -d 'Add git hooks to the repository'
complete -c cog -n "__fish_use_subcommand" -f -a "generate-completions" -d 'Generate shell completions'
complete -c cog -n "__fish_use_subcommand" -f -a "generate-manpages" -d 'Generate manpage'
complete -c cog -n "__fish_use_subcommand" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c cog -n "__fish_seen_subcommand_from check" -s l -l from-latest-tag -d 'Check commit history, starting from the latest tag to HEAD'
complete -c cog -n "__fish_seen_subcommand_from check" -s i -l ignore-merge-commits -d 'Ignore merge commits messages'
complete -c cog -n "__fish_seen_subcommand_from check" -l ignore-fixup-commits -d 'Ignore fixup!, squash! and amend! commit messages'
complete -c cog -n "__fish_seen_subcommand_from check" -s h -l help -d 'Print help'
complete -c cog -n "__fish_seen_subcommand_from commit" -l skip-ci-override -d 'Override and add the <SKIP_CI_OVERRIDE> string to the commit' -r
complete -c cog -n "__fish_seen_subcommand_from commit" -s B -l breaking-change -d 'Create a BREAKING CHANGE commit'
complete -c cog -n "__fish_seen_subcommand_from commit" -s e -l edit -d 'Open commit message in an editor'
complete -c cog -n "__fish_seen_subcommand_from commit" -s s -l sign -d 'Sign this commit'
complete -c cog -n "__fish_seen_subcommand_from commit" -l skip-ci -d 'Add the skip-ci string defined in the cog.toml (or defaults to [skip ci]) to the commit'
complete -c cog -n "__fish_seen_subcommand_from commit" -s a -l add -d 'Add files to the commit (similar to git add .)'
complete -c cog -n "__fish_seen_subcommand_from commit" -s u -l update -d 'Update but doesn\'t add files to the commit (similar to git add -u .)'
complete -c cog -n "__fish_seen_subcommand_from commit" -s h -l help -d 'Print help'
complete -c cog -n "__fish_seen_subcommand_from edit" -s l -l from-latest-tag -d 'Edit non conventional commits, starting from the latest tag to HEAD'
complete -c cog -n "__fish_seen_subcommand_from edit" -s h -l help -d 'Print help'
complete -c cog -n "__fish_seen_subcommand_from log" -s t -l type -d 'Filter on commit type' -r
complete -c cog -n "__fish_seen_subcommand_from log" -s a -l author -d 'Filter on commit author' -r
complete -c cog -n "__fish_seen_subcommand_from log" -s s -l scope -d 'Filter on commit scope' -r
complete -c cog -n "__fish_seen_subcommand_from log" -s B -l breaking-change -d 'Filter BREAKING CHANGE commits'
complete -c cog -n "__fish_seen_subcommand_from log" -s e -l no-error -d 'Omit error on the commit log'
complete -c cog -n "__fish_seen_subcommand_from log" -s h -l help -d 'Print help'
complete -c cog -n "__fish_seen_subcommand_from verify" -s f -l file -d 'Read message from the specified file' -r -F
complete -c cog -n "__fish_seen_subcommand_from verify" -s i -l ignore-merge-commits -d 'Ignore merge commit messages'
complete -c cog -n "__fish_seen_subcommand_from verify" -l ignore-fixup-commits -d 'Ignore fixup!, squash! and amend! commit messages'
complete -c cog -n "__fish_seen_subcommand_from verify" -s h -l help -d 'Print help'
complete -c cog -n "__fish_seen_subcommand_from changelog" -s a -l at -d 'Generate the changelog for a specific git tag' -r
complete -c cog -n "__fish_seen_subcommand_from changelog" -s t -l template -d 'Generate the changelog with the given template' -r
complete -c cog -n "__fish_seen_subcommand_from changelog" -s r -l remote -d 'Url to use during template generation' -r
complete -c cog -n "__fish_seen_subcommand_from changelog" -s o -l owner -d 'Repository owner to use during template generation' -r
complete -c cog -n "__fish_seen_subcommand_from changelog" -l repository -d 'Name of the repository used during template generation' -r
complete -c cog -n "__fish_seen_subcommand_from changelog" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c cog -n "__fish_seen_subcommand_from get-version" -s f -l fallback -d 'Fallback version. Has to be semver compliant' -r
complete -c cog -n "__fish_seen_subcommand_from get-version" -l package -d 'Specify which package to get the version for in a monorepo' -r -f -a "{}"
complete -c cog -n "__fish_seen_subcommand_from get-version" -s h -l help -d 'Print help'
complete -c cog -n "__fish_seen_subcommand_from bump" -l version -d 'Manually set the target version' -r
complete -c cog -n "__fish_seen_subcommand_from bump" -l pre -d 'Set the pre-release version' -r
complete -c cog -n "__fish_seen_subcommand_from bump" -l build -d 'Set the build suffix' -r
complete -c cog -n "__fish_seen_subcommand_from bump" -s H -l hook-profile -d 'Specify the bump profile hooks to run' -r -f -a "{}"
complete -c cog -n "__fish_seen_subcommand_from bump" -l package -d 'Specify which package to bump for monorepo' -r -f -a "{}"
complete -c cog -n "__fish_seen_subcommand_from bump" -s A -l annotated -d 'Annotate tag with given message' -r
complete -c cog -n "__fish_seen_subcommand_from bump" -l skip-ci-override -d 'Override and add the skip-ci string with the provided value to the bump commit' -r
complete -c cog -n "__fish_seen_subcommand_from bump" -s a -l auto -d 'Automatically suggest the target version'
complete -c cog -n "__fish_seen_subcommand_from bump" -s M -l major -d 'Increment the major version'
complete -c cog -n "__fish_seen_subcommand_from bump" -s m -l minor -d 'Increment the minor version'
complete -c cog -n "__fish_seen_subcommand_from bump" -s p -l patch -d 'Increment the patch version'
complete -c cog -n "__fish_seen_subcommand_from bump" -s d -l dry-run -d 'Dry-run: print the target version. No action taken'
complete -c cog -n "__fish_seen_subcommand_from bump" -l skip-ci -d 'Add the skip-ci string defined in the cog.toml (or defaults to [skip ci]) to the bump commit'
complete -c cog -n "__fish_seen_subcommand_from bump" -l skip-untracked -d 'Don\'t fail if there are untracked or uncommitted files'
complete -c cog -n "__fish_seen_subcommand_from bump" -l disable-bump-commit -d 'Disable the creation of the bump commit'
complete -c cog -n "__fish_seen_subcommand_from bump" -s h -l help -d 'Print help'
complete -c cog -n "__fish_seen_subcommand_from init" -s h -l help -d 'Print help'
complete -c cog -n "__fish_seen_subcommand_from install-hook" -s a -l all -d 'Install all git-hooks'
complete -c cog -n "__fish_seen_subcommand_from install-hook" -s o -l overwrite -d 'Overwrite existing git-hooks'
complete -c cog -n "__fish_seen_subcommand_from install-hook" -s h -l help -d 'Print help'
complete -c cog -n "__fish_seen_subcommand_from generate-completions" -s h -l help -d 'Print help'
complete -c cog -n "__fish_seen_subcommand_from generate-manpages" -s h -l help -d 'Print help'
complete -c cog -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from check; and not __fish_seen_subcommand_from commit; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from log; and not __fish_seen_subcommand_from verify; and not __fish_seen_subcommand_from changelog; and not __fish_seen_subcommand_from get-version; and not __fish_seen_subcommand_from bump; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from install-hook; and not __fish_seen_subcommand_from generate-completions; and not __fish_seen_subcommand_from generate-manpages; and not __fish_seen_subcommand_from help" -f -a "check" -d 'Verify all commit messages against the conventional commit specification'
complete -c cog -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from check; and not __fish_seen_subcommand_from commit; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from log; and not __fish_seen_subcommand_from verify; and not __fish_seen_subcommand_from changelog; and not __fish_seen_subcommand_from get-version; and not __fish_seen_subcommand_from bump; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from install-hook; and not __fish_seen_subcommand_from generate-completions; and not __fish_seen_subcommand_from generate-manpages; and not __fish_seen_subcommand_from help" -f -a "commit" -d 'Create a new conventional commit'
complete -c cog -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from check; and not __fish_seen_subcommand_from commit; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from log; and not __fish_seen_subcommand_from verify; and not __fish_seen_subcommand_from changelog; and not __fish_seen_subcommand_from get-version; and not __fish_seen_subcommand_from bump; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from install-hook; and not __fish_seen_subcommand_from generate-completions; and not __fish_seen_subcommand_from generate-manpages; and not __fish_seen_subcommand_from help" -f -a "edit" -d 'Interactively rename invalid commit messages'
complete -c cog -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from check; and not __fish_seen_subcommand_from commit; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from log; and not __fish_seen_subcommand_from verify; and not __fish_seen_subcommand_from changelog; and not __fish_seen_subcommand_from get-version; and not __fish_seen_subcommand_from bump; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from install-hook; and not __fish_seen_subcommand_from generate-completions; and not __fish_seen_subcommand_from generate-manpages; and not __fish_seen_subcommand_from help" -f -a "log" -d 'Like git log but for conventional commits'
complete -c cog -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from check; and not __fish_seen_subcommand_from commit; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from log; and not __fish_seen_subcommand_from verify; and not __fish_seen_subcommand_from changelog; and not __fish_seen_subcommand_from get-version; and not __fish_seen_subcommand_from bump; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from install-hook; and not __fish_seen_subcommand_from generate-completions; and not __fish_seen_subcommand_from generate-manpages; and not __fish_seen_subcommand_from help" -f -a "verify" -d 'Verify a single commit message'
complete -c cog -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from check; and not __fish_seen_subcommand_from commit; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from log; and not __fish_seen_subcommand_from verify; and not __fish_seen_subcommand_from changelog; and not __fish_seen_subcommand_from get-version; and not __fish_seen_subcommand_from bump; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from install-hook; and not __fish_seen_subcommand_from generate-completions; and not __fish_seen_subcommand_from generate-manpages; and not __fish_seen_subcommand_from help" -f -a "changelog" -d 'Display a changelog for the given commit oid range'
complete -c cog -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from check; and not __fish_seen_subcommand_from commit; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from log; and not __fish_seen_subcommand_from verify; and not __fish_seen_subcommand_from changelog; and not __fish_seen_subcommand_from get-version; and not __fish_seen_subcommand_from bump; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from install-hook; and not __fish_seen_subcommand_from generate-completions; and not __fish_seen_subcommand_from generate-manpages; and not __fish_seen_subcommand_from help" -f -a "get-version" -d 'Get current version'
complete -c cog -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from check; and not __fish_seen_subcommand_from commit; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from log; and not __fish_seen_subcommand_from verify; and not __fish_seen_subcommand_from changelog; and not __fish_seen_subcommand_from get-version; and not __fish_seen_subcommand_from bump; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from install-hook; and not __fish_seen_subcommand_from generate-completions; and not __fish_seen_subcommand_from generate-manpages; and not __fish_seen_subcommand_from help" -f -a "bump" -d 'Commit changelog from latest tag to HEAD and create new tag'
complete -c cog -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from check; and not __fish_seen_subcommand_from commit; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from log; and not __fish_seen_subcommand_from verify; and not __fish_seen_subcommand_from changelog; and not __fish_seen_subcommand_from get-version; and not __fish_seen_subcommand_from bump; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from install-hook; and not __fish_seen_subcommand_from generate-completions; and not __fish_seen_subcommand_from generate-manpages; and not __fish_seen_subcommand_from help" -f -a "init" -d 'Install cog config files'
complete -c cog -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from check; and not __fish_seen_subcommand_from commit; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from log; and not __fish_seen_subcommand_from verify; and not __fish_seen_subcommand_from changelog; and not __fish_seen_subcommand_from get-version; and not __fish_seen_subcommand_from bump; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from install-hook; and not __fish_seen_subcommand_from generate-completions; and not __fish_seen_subcommand_from generate-manpages; and not __fish_seen_subcommand_from help" -f -a "install-hook" -d 'Add git hooks to the repository'
complete -c cog -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from check; and not __fish_seen_subcommand_from commit; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from log; and not __fish_seen_subcommand_from verify; and not __fish_seen_subcommand_from changelog; and not __fish_seen_subcommand_from get-version; and not __fish_seen_subcommand_from bump; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from install-hook; and not __fish_seen_subcommand_from generate-completions; and not __fish_seen_subcommand_from generate-manpages; and not __fish_seen_subcommand_from help" -f -a "generate-completions" -d 'Generate shell completions'
complete -c cog -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from check; and not __fish_seen_subcommand_from commit; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from log; and not __fish_seen_subcommand_from verify; and not __fish_seen_subcommand_from changelog; and not __fish_seen_subcommand_from get-version; and not __fish_seen_subcommand_from bump; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from install-hook; and not __fish_seen_subcommand_from generate-completions; and not __fish_seen_subcommand_from generate-manpages; and not __fish_seen_subcommand_from help" -f -a "generate-manpages" -d 'Generate manpage'
complete -c cog -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from check; and not __fish_seen_subcommand_from commit; and not __fish_seen_subcommand_from edit; and not __fish_seen_subcommand_from log; and not __fish_seen_subcommand_from verify; and not __fish_seen_subcommand_from changelog; and not __fish_seen_subcommand_from get-version; and not __fish_seen_subcommand_from bump; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from install-hook; and not __fish_seen_subcommand_from generate-completions; and not __fish_seen_subcommand_from generate-manpages; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'

